@@ -226,7 +226,7 @@
 #define HAVE_INOTIFY_INIT 1
 #define HAVE_INOTIFY_INIT1 1
 #define HAVE_INOTIFY 1
-#define HAVE_LIBUSB 1
+/* #undef HAVE_LIBUSB */
 #define HAVE_O_CLOEXEC 1
 
 /* Apple platforms might be building universal binaries, where Intel builds
@@ -361,7 +361,7 @@
 /* #undef SDL_HAPTIC_DINPUT */
 /* #undef SDL_HAPTIC_XINPUT */
 /* #undef SDL_HAPTIC_ANDROID */
-#define SDL_LIBUSB_DYNAMIC "libusb-1.0.so.0"
+/* #undef SDL_LIBUSB_DYNAMIC */
 #define SDL_UDEV_DYNAMIC "libudev.so.1"
 
 /* Enable various sensor drivers */
